summaryrefslogtreecommitdiff
path: root/Modules/FindLibXslt.cmake
diff options
context:
space:
mode:
authorAlexander Neundorf <neundorf@kde.org>2009-11-22 05:51:38 -0500
committerAlexander Neundorf <neundorf@kde.org>2009-11-22 05:51:38 -0500
commita10198c54e1e9a3798360ffc253325f9f643e272 (patch)
treee30bec47c0eccdcdbead0552dcc56b578bae7e38 /Modules/FindLibXslt.cmake
parent2d9c72c7e50e64baa8ce3905c079f067ee64f806 (diff)
downloadcmake-a10198c54e1e9a3798360ffc253325f9f643e272.tar.gz
don't use deprecated UsePkgConfig.cmake file in FindLibXslt.cmake, some cosmetics
-use find_package(PkgConfig) instead of include(UsePkgConfig) -remove the "if already cached make silent" logic, this is already handled by find_package_handle_standard_args() -remove the if(WIN32) around pkg-config, it shouldn't be necessary Alex
Diffstat (limited to 'Modules/FindLibXslt.cmake')
-rw-r--r--Modules/FindLibXslt.cmake33
1 files changed, 15 insertions, 18 deletions
diff --git a/Modules/FindLibXslt.cmake b/Modules/FindLibXslt.cmake
index 5c3953a5b2..d16d1ffef3 100644
--- a/Modules/FindLibXslt.cmake
+++ b/Modules/FindLibXslt.cmake
@@ -1,4 +1,4 @@
# - Try to find LibXslt
# Once done this will define
#
# LIBXSLT_FOUND - system has LibXslt
@@ -20,26 +20,23 @@
# (To distributed this file outside of CMake, substitute the full
# License text for the above reference.)
-IF (LIBXSLT_INCLUDE_DIR AND LIBXSLT_LIBRARIES)
- # in cache already
- SET(LibXslt_FIND_QUIETLY TRUE)
-ENDIF (LIBXSLT_INCLUDE_DIR AND LIBXSLT_LIBRARIES)
-
-IF (NOT WIN32)
- # use pkg-config to get the directories and then use these values
- # in the FIND_PATH() and FIND_LIBRARY() calls
- INCLUDE(UsePkgConfig)
- PKGCONFIG(libxslt _LibXsltIncDir _LibXsltLinkDir _LibXsltLinkFlags _LibXsltCflags)
- SET(LIBXSLT_DEFINITIONS ${_LibXsltCflags})
-ENDIF (NOT WIN32)
-
-FIND_PATH(LIBXSLT_INCLUDE_DIR libxslt/xslt.h
- ${_LibXsltIncDir}
+# use pkg-config to get the directories and then use these values
+# in the FIND_PATH() and FIND_LIBRARY() calls
+FIND_PACKAGE(PkgConfig)
+PKG_CHECK_MODULES(PC_LIBXSLT libxslt)
+SET(LIBXSLT_DEFINITIONS ${PC_LIBXSLT_CFLAGS_OTHER})
+
+
+FIND_PATH(LIBXSLT_INCLUDE_DIR NAMES libxslt/xslt.h
+ HINTS
+ ${PC_LIBXSLT_INCLUDEDIR}
+ ${PC_LIBXSLT_INCLUDE_DIRS}
)
FIND_LIBRARY(LIBXSLT_LIBRARIES NAMES xslt libxslt
- PATHS
- ${_LibXsltLinkDir}
+ HINTS
+ ${PC_LIBXSLT_LIBDIR}
+ ${PC_LIBXSLT_LIBRARY_DIRS}
)
INCLUDE(FindPackageHandleStandardArgs)
@@ -1,4 +1,4 @@
-# - Try to find LibXslt
+# - Try to find the LibXslt library
# Once done this will define
#